@@ -6,24 +6,6 @@
 
 from importlib import util
 
+# Import files dependent on package installations.
 __EXTRAS__ = util.find_spec("captum") or util.find_spec("tf_explain")
 __MODELS__ = util.find_spec("torch") or util.find_spec("tensorflow")
-
-from .asserts import *
-from .constants import *
-from .norm_func import *
-from .normalise_func import *
-from .mosaic_func import *
-from .loss_func import *
-from .discretise_func import *
-from .perturb_func import *
-from .plotting import *
-from .similarity_func import *
-from .utils import *
-from .warn_func import *
-
-# Import files dependent on package installations.
-if __MODELS__:
-    from .models import *
-if __EXTRAS__:
-    from .explanation_func import *
