@@ -1,23 +1,23 @@
 """This module implements the base class for creating evaluation metrics."""
-
 # This file is part of Quantus.
 # Quantus is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 # Quantus is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 # You should have received a copy of the GNU Lesser General Public License along with Quantus. If not, see <https://www.gnu.org/licenses/>.
 # Quantus project URL: <https://github.com/understandable-machine-intelligence-lab/Quantus>.
 
-import warnings
+import inspect
+import re
 from abc import abstractmethod
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
-
+from collections.abc import Sequence
+from typing import Any, Callable, Dict, Sequence, Optional, Tuple, Union, Collection
 import matplotlib.pyplot as plt
 import numpy as np
 from tqdm.auto import tqdm
 
-from ..helpers import utils
-from ..helpers import asserts
-from ..helpers.model_interface import ModelInterface
-from ..helpers import warn_func
+from quantus.helpers import asserts
+from quantus.helpers import utils
+from quantus.helpers import warn
+from quantus.helpers.model.model_interface import ModelInterface
 
 
 class Metric:
@@ -30,10 +30,10 @@ class Metric:
         self,
         abs: bool,
         normalise: bool,
-        normalise_func: Optional[Callable],
+        normalise_func: Callable,
         normalise_func_kwargs: Optional[Dict[str, Any]],
         return_aggregate: bool,
-        aggregate_func: Optional[Callable],
+        aggregate_func: Callable,
         default_plot_func: Optional[Callable],
         disable_warnings: bool,
         display_progressbar: bool,
@@ -45,12 +45,16 @@ class Metric:
         Each of the defined metrics in Quantus, inherits from Metric base class.
 
         A child metric can benefit from the following class methods:
-        - __call__(): Will call general_preprocess(), apply () on each
+        - __call__(): Will call general_preprocess(), apply evaluate_instance() on each
                       instance and finally call custom_preprocess().
-                      To use this method the child Metric needs to implement ().
+                      To use this method the child Metric needs to implement
+                      evaluate_instance().
         - general_preprocess(): Prepares all necessary data structures for evaluation.
                                 Will call custom_preprocess() at the end.
 
+        The content of last_results will be appended to all_results (list) at the end of
+        the evaluation call.
+
         Parameters
         ----------
         abs: boolean
@@ -64,7 +68,7 @@ class Metric:
         return_aggregate: boolean
             Indicates if an aggregated score should be computed over all instances.
         aggregate_func: callable
-            Callable that aggregates the scores given an evaluation call..
+            Callable that aggregates the scores given an evaluation call.
         default_plot_func: callable
             Callable that plots the metrics result.
         disable_warnings: boolean
@@ -74,10 +78,9 @@ class Metric:
         kwargs: optional
             Keyword arguments.
         """
-
         # Run deprecation warnings.
-        warn_func.deprecation_warnings(kwargs)
-        warn_func.check_kwargs(kwargs)
+        warn.deprecation_warnings(kwargs)
+        warn.check_kwargs(kwargs)
 
         self.abs = abs
         self.normalise = normalise
@@ -93,10 +96,10 @@ class Metric:
         self.disable_warnings = disable_warnings
         self.display_progressbar = display_progressbar
 
-        self.a_axes = None
+        self.a_axes: Sequence[int] = None
 
-        self.last_results = []
-        self.all_results = []
+        self.last_results: Any = []
+        self.all_results: Any = []
 
     def __call__(
         self,
@@ -107,25 +110,29 @@ class Metric:
         s_batch: Optional[np.ndarray],
         channel_first: Optional[bool],
         explain_func: Optional[Callable],
-        explain_func_kwargs: Optional[Dict[str, Any]],
+        explain_func_kwargs: Optional[Dict],
         model_predict_kwargs: Optional[Dict],
         softmax: Optional[bool],
         device: Optional[str] = None,
+        batch_size: int = 64,
         custom_batch: Optional[Any] = None,
         **kwargs,
-    ) -> Union[int, float, list, dict, None]:
+    ) -> Union[int, float, list, dict, Collection[Any], None]:
         """
         This implementation represents the main logic of the metric and makes the class object callable.
         It completes instance-wise evaluation of explanations (a_batch) with respect to input data (x_batch),
         output labels (y_batch) and a torch or tensorflow model (model).
 
         Calls general_preprocess() with all relevant arguments, calls
-        () on each instance, and saves results to last_results.
+        evaluate_instance() on each instance, and saves results to last_results.
         Calls custom_postprocess() afterwards. Finally returns last_results.
 
+        The content of last_results will be appended to all_results (list) at the end of
+        the evaluation call.
+
         Parameters
         ----------
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -192,18 +199,10 @@ class Metric:
         """
 
         # Run deprecation warnings.
-        warn_func.deprecation_warnings(kwargs)
-        warn_func.check_kwargs(kwargs)
+        warn.deprecation_warnings(kwargs)
+        warn.check_kwargs(kwargs)
 
-        (
-            model,
-            x_batch,
-            y_batch,
-            a_batch,
-            s_batch,
-            custom_batch,
-            custom_preprocess_batch,
-        ) = self.general_preprocess(
+        data = self.general_preprocess(
             model=model,
             x_batch=x_batch,
             y_batch=y_batch,
@@ -218,52 +217,16 @@ class Metric:
             custom_batch=custom_batch,
         )
 
-        # Create progress bar if desired.
-        iterator = tqdm(
-            enumerate(
-                zip(
-                    x_batch,
-                    y_batch,
-                    a_batch,
-                    s_batch,
-                    custom_batch,
-                    custom_preprocess_batch,
-                )
-            ),
-            total=len(x_batch),
-            disable=not self.display_progressbar,
-            desc=f"Evaluating {self.__class__.__name__}",
-        )
         self.last_results = [None for _ in x_batch]
-        for id_instance, (
-            x_instance,
-            y_instance,
-            a_instance,
-            s_instance,
-            c_instance,
-            p_instance,
-        ) in iterator:
-            result = self.evaluate_instance(
-                i=int(id_instance),
-                model=model,
-                x=x_instance,
-                y=y_instance,
-                a=a_instance,
-                s=s_instance,
-                c=c_instance,
-                p=p_instance,
-            )
+
+        # Evaluate with instace given the metric.
+        iterator = self.get_instance_iterator(data=data)
+        for id_instance, data_instance in iterator:
+            result = self.evaluate_instance(**data_instance)
             self.last_results[id_instance] = result
 
         # Call custom post-processing.
-        self.custom_postprocess(
-            model=model,
-            x_batch=x_batch,
-            y_batch=y_batch,
-            a_batch=a_batch,
-            s_batch=s_batch,
-            custom_batch=custom_batch,
-        )
+        self.custom_postprocess(**data)
 
         if self.return_aggregate:
             if self.aggregate_func:
@@ -287,14 +250,11 @@ class Metric:
     @abstractmethod
     def evaluate_instance(
         self,
-        i: int,
         model: ModelInterface,
         x: np.ndarray,
-        y: Optional[np.ndarray] = None,
-        a: Optional[np.ndarray] = None,
-        s: Optional[np.ndarray] = None,
-        c: Optional[np.ndarray] = None,
-        p: Optional[np.ndarray] = None,
+        y: Optional[np.ndarray],
+        a: Optional[np.ndarray],
+        s: Optional[np.ndarray],
     ) -> Any:
         """
         Evaluate instance gets model and data for a single instance as input and returns the evaluation result.
@@ -303,8 +263,6 @@ class Metric:
 
         Parameters
         ----------
-        i: integer
-            The evaluation instance.
         model: ModelInterface
             A ModelInteface that is subject to explanation.
         x: np.ndarray
@@ -315,10 +273,10 @@ class Metric:
             The explanation to be evaluated on an instance-basis.
         s: np.ndarray
             The segmentation to be evaluated on an instance-basis.
-        c: any
-            The custom input to be evaluated on an instance-basis.
-        p: any
-            The custom preprocess input to be evaluated on an instance-basis.
+
+        Returns
+        -------
+        Any
         """
         raise NotImplementedError()
 
@@ -330,15 +288,13 @@ class Metric:
         a_batch: Optional[np.ndarray],
         s_batch: Optional[np.ndarray],
         channel_first: Optional[bool],
-        explain_func: Optional[Callable],
+        explain_func: Callable,
         explain_func_kwargs: Optional[Dict[str, Any]],
         model_predict_kwargs: Optional[Dict],
         softmax: bool,
         device: Optional[str],
         custom_batch: Optional[np.ndarray],
-    ) -> Tuple[
-        ModelInterface, np.ndarray, np.ndarray, np.ndarray, np.ndarray, Any, Any
-    ]:
+    ) -> Dict[str, Any]:
         """
         Prepares all necessary variables for evaluation.
 
@@ -357,7 +313,7 @@ class Metric:
         Parameters
         ----------
 
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model e.g., torchvision.models that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -383,8 +339,6 @@ class Metric:
             Indicated the device on which a torch.Tensor is or will be allocated: "cpu" or "gpu".
         custom_batch: any
             Gives flexibility ot the user to use for evaluation, can hold any variable.
-        kwargs: optional
-            Keyword arguments.
 
         Returns
         -------
@@ -442,51 +396,41 @@ class Metric:
         # Infer attribution axes for perturbation function.
         self.a_axes = utils.infer_attribution_axes(a_batch, x_batch)
 
+        # Initialize data dictionary.
+        data = {
+            "model": model,
+            "x_batch": x_batch,
+            "y_batch": y_batch,
+            "a_batch": a_batch,
+            "s_batch": s_batch,
+            "custom_batch": custom_batch,
+        }
+
         # Call custom pre-processing from inheriting class.
-        (
-            model,
-            x_batch,
-            y_batch,
-            a_batch,
-            s_batch,
-            custom_batch,
-            custom_preprocess_batch,
-        ) = self.custom_preprocess(
-            model=model,
-            x_batch=x_batch,
-            y_batch=y_batch,
-            a_batch=a_batch,
-            s_batch=s_batch,
-            custom_batch=custom_batch,
-        )
+        custom_preprocess_dict = self.custom_preprocess(**data)
+
+        # Save data coming from custom preprocess to data dict.
+        if custom_preprocess_dict:
+            for key, value in custom_preprocess_dict.items():
+                data[key] = value
+
+        # Remove custom_batch if not used.
+        if data["custom_batch"] is None:
+            del data["custom_batch"]
 
         # Normalise with specified keyword arguments if requested.
         if self.normalise:
-            a_batch = self.normalise_func(
-                a=a_batch,
-                normalized_axes=list(range(np.ndim(a_batch)))[1:],
+            data["a_batch"] = self.normalise_func(
+                a=data["a_batch"],
+                normalise_axes=list(range(np.ndim(data["a_batch"])))[1:],
                 **self.normalise_func_kwargs,
             )
 
         # Take absolute if requested.
         if self.abs:
-            a_batch = np.abs(a_batch)
+            data["a_batch"] = np.abs(data["a_batch"])
 
-        # This is needed for iterator (zipped over x_batch, y_batch, a_batch, s_batch, custom_batch).
-        if s_batch is None:
-            s_batch = [None for _ in x_batch]
-        if custom_batch is None:
-            custom_batch = [None for _ in x_batch]
-
-        return (
-            model,
-            x_batch,
-            y_batch,
-            a_batch,
-            s_batch,
-            custom_batch,
-            custom_preprocess_batch,
-        )
+        return data
 
     def custom_preprocess(
         self,
@@ -496,21 +440,24 @@ class Metric:
         a_batch: Optional[np.ndarray],
         s_batch: np.ndarray,
         custom_batch: Optional[np.ndarray],
-    ) -> Tuple[
-        ModelInterface, np.ndarray, np.ndarray, np.ndarray, np.ndarray, Any, Any
-    ]:
+    ) -> Optional[Dict[str, Any]]:
         """
         Implement this method if you need custom preprocessing of data,
-        model alteration or simply for creating/initialising additional attributes.
+        model alteration or simply for creating/initialising additional
+        attributes or assertions.
 
-        If this function is implemented for your metric, make sure to add in the metric-specific
-        function custom_preprocess():
-
-        >> custom_preprocess_batch = [None for _ in x_batch]
+        If this method returns a dictionary, the keys (string) will be used as
+        additional arguments for evaluate_instance().
+        If the key ends with `_batch`, this suffix will be removed from the
+        respective argument name when passed to evaluate_instance().
+        If they key corresponds to the arguments `x_batch, y_batch, a_batch, s_batch`,
+        these will be overwritten for passing `x, y, a, s` to `evaluate_instance()`.
+        If this method returns None, no additional keyword arguments will be
+        passed to `evaluate_instance()`.
 
         Parameters
         ----------
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model e.g., torchvision.models that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -521,25 +468,180 @@ class Metric:
         s_batch: np.ndarray, optional
             A np.ndarray which contains segmentation masks that matches the input.
         custom_batch: any
-            Gives flexibility ot the user to use for evaluation, can hold any variable.
+            Gives flexibility to the inheriting metric to use for evaluation, can hold any variable.
 
         Returns
         -------
-        tuple
-            In addition to the x_batch, y_batch, a_batch, s_batch and custom_batch,
-            returning a custom preprocess batch (custom_preprocess_batch).
+        dict, optional
+            A dictionary which holds (optionally additional) preprocessed data to
+           be included when calling `evaluate_instance()`.
+
+
+        Examples
+        --------
+            # Custom Metric definition with additional keyword argument used in evaluate_instance():
+            >>> def custom_preprocess(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x_batch: np.ndarray,
+            >>>     y_batch: Optional[np.ndarray],
+            >>>     a_batch: Optional[np.ndarray],
+            >>>     s_batch: np.ndarray,
+            >>>     custom_batch: Optional[np.ndarray],
+            >>> ) -> Dict[str, Any]:
+            >>>     return {'my_new_variable': np.mean(x_batch)}
+            >>>
+            >>> def evaluate_instance(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x: np.ndarray,
+            >>>     y: Optional[np.ndarray],
+            >>>     a: Optional[np.ndarray],
+            >>>     s: np.ndarray,
+            >>>     my_new_variable: np.float,
+            >>> ) -> float:
+
+            # Custom Metric definition with additional keyword argument that ends with `_batch`
+            >>> def custom_preprocess(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x_batch: np.ndarray,
+            >>>     y_batch: Optional[np.ndarray],
+            >>>     a_batch: Optional[np.ndarray],
+            >>>     s_batch: np.ndarray,
+            >>>     custom_batch: Optional[np.ndarray],
+            >>> ) -> Dict[str, Any]:
+            >>>     return {'my_new_variable_batch': np.arange(len(x_batch))}
+            >>>
+            >>> def evaluate_instance(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x: np.ndarray,
+            >>>     y: Optional[np.ndarray],
+            >>>     a: Optional[np.ndarray],
+            >>>     s: np.ndarray,
+            >>>     my_new_variable: np.int,
+            >>> ) -> float:
+
+            # Custom Metric definition with transformation of an existing
+            # keyword argument from `evaluate_instance()`
+            >>> def custom_preprocess(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x_batch: np.ndarray,
+            >>>     y_batch: Optional[np.ndarray],
+            >>>     a_batch: Optional[np.ndarray],
+            >>>     s_batch: np.ndarray,
+            >>>     custom_batch: Optional[np.ndarray],
+            >>> ) -> Dict[str, Any]:
+            >>>     return {'x_batch': x_batch - np.mean(x_batch, axis=0)}
+            >>>
+            >>> def evaluate_instance(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x: np.ndarray,
+            >>>     y: Optional[np.ndarray],
+            >>>     a: Optional[np.ndarray],
+            >>>     s: np.ndarray,
+            >>> ) -> float:
+
+            # Custom Metric definition with None returned in custom_preprocess(),
+            # but with inplace-preprocessing and additional assertion.
+            >>> def custom_preprocess(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x_batch: np.ndarray,
+            >>>     y_batch: Optional[np.ndarray],
+            >>>     a_batch: Optional[np.ndarray],
+            >>>     s_batch: np.ndarray,
+            >>>     custom_batch: Optional[np.ndarray],
+            >>> ) -> None:
+            >>>     if np.any(np.all(a_batch < 0, axis=0)):
+            >>>         raise ValueError("Attributions must not be all negative")
+            >>>
+            >>>     x_batch -= np.mean(x_batch, axis=0)
+            >>>
+            >>>     return None
+            >>>
+            >>> def evaluate_instance(
+            >>>     self,
+            >>>     model: ModelInterface,
+            >>>     x: np.ndarray,
+            >>>     y: Optional[np.ndarray],
+            >>>     a: Optional[np.ndarray],
+            >>>     s: np.ndarray,
+            >>> ) -> float:
+
         """
-        custom_preprocess_batch = [None for _ in x_batch]
-        return (
-            model,
-            x_batch,
-            y_batch,
-            a_batch,
-            s_batch,
-            custom_batch,
-            custom_preprocess_batch,
+        pass
+
+    def get_instance_iterator(self, data: Dict[str, Any]):
+        """
+        Creates iterator to iterate over all instances in data dictionary.
+        Each iterator output element is a keyword argument dictionary with
+        string keys.
+
+        Each item key in the input data dictionary has to be of type string.
+        - If the item value is not a sequence, the respective item key/value pair
+          will be written to each iterator output dictionary.
+        - If the item value is a sequence and the item key ends with '_batch',
+          a check will be made to make sure length matches number of instances.
+          The value of each instance in the sequence will be added to the respective
+          iterator output dictionary with the '_batch' suffix removed.
+        - If the item value is a sequence but doesn't end with '_batch', it will be treated
+          as a simple value and the respective item key/value pair will be
+          written to each iterator output dictionary.
+
+        Parameters
+        ----------
+        data: dict[str, any]
+            The data input dictionary.
+
+        Returns
+        -------
+        iterator
+            Each iterator output element is a keyword argument dictionary (string keys).
+
+        """
+        n_instances = len(data["x_batch"])
+
+        for key, value in data.items():
+            # If data-value is not a Sequence or a string, create list of repeated values with length of n_instances.
+            if not isinstance(value, (Sequence, np.ndarray)) or isinstance(value, str):
+                data[key] = [value for _ in range(n_instances)]
+
+            # If data-value is a sequence and ends with '_batch', only check for correct length.
+            elif key.endswith("_batch"):
+                if len(value) != n_instances:
+                    # Sequence has to have correct length.
+                    raise ValueError(
+                        f"'{key}' has incorrect length (expected: {n_instances}, is: {len(value)})"
+                    )
+
+            # If data-value is a sequence and doesn't end with '_batch', create
+            # list of repeated sequences with length of n_instances.
+            else:
+                data[key] = [value for _ in range(n_instances)]
+
+        # We create a list of dictionaries where each dictionary holds all data for a single instance.
+        # We remove the '_batch' suffix if present.
+        data_instances = [
+            {
+                re.sub("_batch", "", key): value[id_instance]
+                for key, value in data.items()
+            }
+            for id_instance in range(n_instances)
+        ]
+
+        iterator = tqdm(
+            enumerate(data_instances),
+            total=n_instances,
+            disable=not self.display_progressbar,  # Create progress bar if desired.
+            desc=f"Evaluating {self.__class__.__name__}",
         )
 
+        return iterator
+
     def custom_postprocess(
         self,
         model: ModelInterface,
@@ -547,7 +649,7 @@ class Metric:
         y_batch: Optional[np.ndarray],
         a_batch: Optional[np.ndarray],
         s_batch: np.ndarray,
-        custom_batch: Optional[np.ndarray],
+        **kwargs,
     ) -> Optional[Any]:
         """
         Implement this method if you need custom postprocessing of results or
@@ -555,7 +657,7 @@ class Metric:
 
         Parameters
         ----------
-        model: Union[torch.nn.Module, tf.keras.Model]
+        model: torch.nn.Module, tf.keras.Model
             A torch or tensorflow model e.g., torchvision.models that is subject to explanation.
         x_batch: np.ndarray
             A np.ndarray which contains the input data that are explained.
@@ -565,19 +667,19 @@ class Metric:
             A np.ndarray which contains pre-computed attributions i.e., explanations.
         s_batch: np.ndarray, optional
             A np.ndarray which contains segmentation masks that matches the input.
-        custom_batch: any
-            Gives flexibility ot the user to use for evaluation, can hold any variable.
+        kwargs: any, optional
+            Additional data which was created in custom_preprocess().
 
         Returns
         -------
         any
-            Can be implemented, optionally by the user.
+            Can be implemented, optionally by the child class.
         """
         pass
 
     def plot(
         self,
-        plot_func: Union[Callable, None] = None,
+        plot_func: Callable,
         show: bool = True,
         path_to_save: Union[str, None] = None,
         *args,
@@ -645,8 +747,6 @@ class Metric:
             "all_results",
             "last_results",
             "default_plot_func",
-            "disable_warnings",
-            "display_progressbar",
         ]
         return {k: v for k, v in self.__dict__.items() if k not in attr_exclude}
 
@@ -664,12 +764,12 @@ class PerturbationMetric(Metric):
         self,
         abs: bool,
         normalise: bool,
-        normalise_func: Optional[Callable],
+        normalise_func: Callable,
         normalise_func_kwargs: Optional[Dict[str, Any]],
         perturb_func: Callable,
         perturb_func_kwargs: Optional[Dict[str, Any]],
         return_aggregate: bool,
-        aggregate_func: Optional[Callable],
+        aggregate_func: Callable,
         default_plot_func: Optional[Callable],
         disable_warnings: bool,
         display_progressbar: bool,
@@ -678,6 +778,8 @@ class PerturbationMetric(Metric):
         """
         Initialise the PerturbationMetric base class.
 
+        Parameters
+        ----------
         Parameters
         ----------
         abs: boolean
@@ -690,12 +792,12 @@ class PerturbationMetric(Metric):
             Keyword arguments to be passed to normalise_func on call.
         perturb_func: callable
             Input perturbation function.
-        perturb_func_kwargs: dict
-            Keyword arguments to be passed to perturb_func, default={}.
+        perturb_func_kwargs: dict, optional
+            Keyword arguments to be passed to perturb_func.
         return_aggregate: boolean
             Indicates if an aggregated score should be computed over all instances.
         aggregate_func: callable
-            Callable that aggregates the scores given an evaluation call..
+            Callable that aggregates the scores given an evaluation call.
         default_plot_func: callable
             Callable that plots the metrics result.
         disable_warnings: boolean
@@ -706,7 +808,7 @@ class PerturbationMetric(Metric):
             Keyword arguments.
         """
 
-        # Initialise super-class with passed parameters.
+        # Initialize super-class with passed parameters
         super().__init__(
             abs=abs,
             normalise=normalise,
@@ -720,9 +822,42 @@ class PerturbationMetric(Metric):
             **kwargs,
         )
 
+        # Save perturbation metric attributes.
         self.perturb_func = perturb_func
 
         if perturb_func_kwargs is None:
             perturb_func_kwargs = {}
-
         self.perturb_func_kwargs = perturb_func_kwargs
+
+    @abstractmethod
+    def evaluate_instance(
+        self,
+        model: ModelInterface,
+        x: np.ndarray,
+        y: Optional[np.ndarray],
+        a: Optional[np.ndarray],
+        s: Optional[np.ndarray],
+    ) -> Any:
+        """
+        Evaluate instance gets model and data for a single instance as input and returns the evaluation result.
+
+        This method needs to be implemented to use __call__().
+
+        Parameters
+        ----------
+        model: ModelInterface
+            A ModelInteface that is subject to explanation.
+        x: np.ndarray
+            The input to be evaluated on an instance-basis.
+        y: np.ndarray
+            The output to be evaluated on an instance-basis.
+        a: np.ndarray
+            The explanation to be evaluated on an instance-basis.
+        s: np.ndarray
+            The segmentation to be evaluated on an instance-basis.
+
+        Returns
+        -------
+        Any
+        """
+        raise NotImplementedError()
