@@ -1,18 +1,10 @@
-from typing import Tuple
-import os
 import pytest
 import pickle
 import torch
-import torchvision
-from torchvision import transforms
 import numpy as np
-import tensorflow as tf
-from tensorflow.keras.models import load_model
 from tensorflow.keras.datasets import cifar10
 
-from ..quantus.helpers.models import LeNet, LeNetTF, ConvNet1D, ConvNet1DTF
-from ..quantus.helpers.pytorch_model import PyTorchModel
-from ..quantus.helpers.tf_model import TensorFlowModel
+from quantus.helpers.model.models import LeNet, LeNetTF, ConvNet1D, ConvNet1DTF
 
 
 @pytest.fixture(scope="session", autouse=True)
@@ -81,8 +73,7 @@ def load_1d_3ch_conv_model_tf():
 def load_mnist_images():
     """Load a batch of MNIST digits: inputs and outputs to use for testing."""
     x_batch = torch.as_tensor(
-        np.loadtxt("tests/assets/mnist_x").reshape(124, 1, 28, 28),
-        dtype=torch.float,
+        np.loadtxt("tests/assets/mnist_x").reshape(124, 1, 28, 28), dtype=torch.float,
     ).numpy()
     y_batch = torch.as_tensor(
         np.loadtxt("tests/assets/mnist_y"), dtype=torch.int64
@@ -95,8 +86,7 @@ def load_cifar10_images():
     """Load a batch of Cifar10 digits: inputs and outputs to use for testing."""
     (x_train, y_train), (x_test, y_test) = cifar10.load_data()
     x_batch = torch.as_tensor(
-        x_train[:124, ...].reshape(124, 3, 32, 32),
-        dtype=torch.float,
+        x_train[:124, ...].reshape(124, 3, 32, 32), dtype=torch.float,
     ).numpy()
     y_batch = torch.as_tensor(y_train[:124].reshape(124), dtype=torch.int64).numpy()
     return {"x_batch": x_batch, "y_batch": y_batch}
@@ -106,8 +96,7 @@ def load_cifar10_images():
 def load_mnist_images_tf():
     """Load a batch of MNIST digits: inputs and outputs to use for testing."""
     x_batch = torch.as_tensor(
-        np.loadtxt("tests/assets/mnist_x").reshape(124, 1, 28, 28),
-        dtype=torch.float,
+        np.loadtxt("tests/assets/mnist_x").reshape(124, 1, 28, 28), dtype=torch.float,
     ).numpy()
     y_batch = torch.as_tensor(
         np.loadtxt("tests/assets/mnist_y"), dtype=torch.int64
