@@ -1,11 +1,10 @@
 from typing import Union
 
-import numpy as np
 import pytest
 from pytest_lazyfixture import lazy_fixture
 
-from ..fixtures import *
-from ...quantus.helpers import *
+from quantus.functions.norm_func import *
+from tests.fixtures import *
 
 
 @pytest.fixture
