@@ -1,14 +1,14 @@
-import numpy as np
-import pytest
 from functools import reduce
 from operator import and_
 from typing import Union
-from scipy.special import softmax
-from pytest_lazyfixture import lazy_fixture
 
-from ..fixtures import *
-from ...quantus.helpers import *
-from ...quantus.helpers.tf_model import TensorFlowModel
+import numpy as np
+import pytest
+from pytest_lazyfixture import lazy_fixture
+from scipy.special import softmax
+
+from tests.fixtures import *
+from quantus.helpers.model.tf_model import TensorFlowModel
 
 
 @pytest.fixture
@@ -22,10 +22,7 @@ def mock_input_tf_array():
     [
         (
             lazy_fixture("mock_input_tf_array"),
-            {
-                "softmax": False,
-                "channel_first": False,
-            },
+            {"softmax": False, "channel_first": False,},
             np.array(
                 [
                     -0.723556,
@@ -43,10 +40,7 @@ def mock_input_tf_array():
         ),
         (
             lazy_fixture("mock_input_tf_array"),
-            {
-                "softmax": True,
-                "channel_first": False,
-            },
+            {"softmax": True, "channel_first": False,},
             softmax(
                 np.array(
                     [
